@@ -33,7 +33,7 @@
 #----------------------------------------------------------------------
 
 
-"""Support for Berkeley DB 4.2 through 5.1 with a simple interface.
+"""Support for Berkeley DB 4.3 through 5.3 with a simple interface.
 
 For the full featured object oriented interface use the bsddb.db module
 instead.  It mirrors the Oracle Berkeley DB C API.
@@ -42,28 +42,12 @@ instead.  It mirrors the Oracle Berkeley DB C API.
 import sys
 absolute_import = (sys.version_info[0] >= 3)
 
-if (sys.version_info >= (2, 6)) and (sys.version_info < (3, 0)) :
-    if sys.py3kwarning and (__name__ != 'bsddb3') :
-        import warnings
-        warnings.warnpy3k("in 3.x, the bsddb module has been removed; "
-                          "please use the pybsddb project instead",
-                          DeprecationWarning, 2)
-
 try:
-    if __name__ == 'bsddb3':
-        # import _pybsddb binary as it should be the more recent version from
-        # a standalone pybsddb addon package than the version included with
-        # python as bsddb._bsddb.
-        if absolute_import :
-            # Because this syntaxis is not valid before Python 2.5
-            exec("from . import _pybsddb")
-        else :
-            import _pybsddb
-        _bsddb = _pybsddb
-        from bsddb3.dbutils import DeadlockWrap as _DeadlockWrap
-    else:
-        import _bsddb
-        from bsddb.dbutils import DeadlockWrap as _DeadlockWrap
+    if absolute_import :
+        from . import _pybsddb
+    else :
+        import _pybsddb
+    from bsddb3.dbutils import DeadlockWrap as _DeadlockWrap
 except ImportError:
     # Remove ourselves from sys.modules
     import sys
@@ -71,7 +55,7 @@ except ImportError:
     raise
 
 # bsddb3 calls it db, but provide _db for backwards compatibility
-db = _db = _bsddb
+db = _db = _pybsddb
 __version__ = db.__version__
 
 error = db.DBError  # So bsddb.error will mean something...
@@ -82,12 +66,8 @@ import sys, os
 
 from weakref import ref
 
-if sys.version_info < (2, 6) :
-    import UserDict
-    MutableMapping = UserDict.DictMixin
-else :
-    import collections
-    MutableMapping = collections.MutableMapping
+import collections
+MutableMapping = collections.MutableMapping
 
 class _iter_mixin(MutableMapping):
     def _make_iter_cursor(self):
@@ -122,7 +102,7 @@ class _iter_mixin(MutableMapping):
                     try:
                         key = _DeadlockWrap(next, 0,0,0)[0]
                         yield key
-                    except _bsddb.DBCursorClosedError:
+                    except _db.DBCursorClosedError:
                         if self._kill_iteration:
                             raise RuntimeError('Database changed size '
                                                'during iteration.')
@@ -131,17 +111,13 @@ class _iter_mixin(MutableMapping):
                         # be closed by another thread before this call.
                         _DeadlockWrap(cur.set, key,0,0,0)
                         next = getattr(cur, "next")
-            except _bsddb.DBNotFoundError:
+            except _db.DBNotFoundError:
                 pass
-            except _bsddb.DBCursorClosedError:
+            except _db.DBCursorClosedError:
                 # the database was modified during iteration.  abort.
                 pass
-# When Python 2.3 not supported in bsddb3, we can change this to "finally"
-        except :
+        finally :
             self._in_iter -= 1
-            raise
-
-        self._in_iter -= 1
 
     def iteritems(self):
         if not self.db:
@@ -165,7 +141,7 @@ class _iter_mixin(MutableMapping):
                         kv = _DeadlockWrap(next)
                         key = kv[0]
                         yield kv
-                    except _bsddb.DBCursorClosedError:
+                    except _db.DBCursorClosedError:
                         if self._kill_iteration:
                             raise RuntimeError('Database changed size '
                                                'during iteration.')
@@ -174,17 +150,13 @@ class _iter_mixin(MutableMapping):
                         # be closed by another thread before this call.
                         _DeadlockWrap(cur.set, key,0,0,0)
                         next = getattr(cur, "next")
-            except _bsddb.DBNotFoundError:
+            except _db.DBNotFoundError:
                 pass
-            except _bsddb.DBCursorClosedError:
+            except _db.DBCursorClosedError:
                 # the database was modified during iteration.  abort.
                 pass
-# When Python 2.3 not supported in bsddb3, we can change this to "finally"
-        except :
+        finally :
             self._in_iter -= 1
-            raise
-
-        self._in_iter -= 1
 
 
 class _DBWithCursor(_iter_mixin):
@@ -257,11 +229,10 @@ class _DBWithCursor(_iter_mixin):
         self._checkOpen()
         return _DeadlockWrap(lambda: len(self.db))  # len(self.db)
 
-    if sys.version_info >= (2, 6) :
-        def __repr__(self) :
-            if self.isOpen() :
-                return repr(dict(_DeadlockWrap(self.db.items)))
-            return repr(dict())
+    def __repr__(self) :
+        if self.isOpen() :
+            return repr(dict(_DeadlockWrap(self.db.items)))
+        return repr(dict())
 
     def __getitem__(self, key):
         self._checkOpen()
