@@ -1,3 +1,38 @@
+"""
+Copyright (c) 2008-2014, Jesus Cea Avion <jcea@jcea.es>
+All rights reserved.
+
+Redistribution and use in source and binary forms, with or without
+modification, are permitted provided that the following conditions
+are met:
+
+    1. Redistributions of source code must retain the above copyright
+    notice, this list of conditions and the following disclaimer.
+
+    2. Redistributions in binary form must reproduce the above
+    copyright notice, this list of conditions and the following
+    disclaimer in the documentation and/or other materials provided
+    with the distribution.
+
+    3. Neither the name of Jesus Cea Avion nor the names of its
+    contributors may be used to endorse or promote products derived
+    from this software without specific prior written permission.
+
+    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
+    CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
+    INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
+    MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
+    BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
+            TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+            DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
+    ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
+    TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
+    THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+    SUCH DAMAGE.
+    """
+
 """
 TestCases for DB.associate.
 """
@@ -76,11 +111,6 @@ musicdata = {
 #----------------------------------------------------------------------
 
 class AssociateErrorTestCase(unittest.TestCase):
-    import sys
-    if sys.version_info < (2, 4) :
-        def assertTrue(self, expr, msg=None):
-            self.failUnless(expr,msg=msg)
-
     def setUp(self):
         self.filename = self.__class__.__name__ + '.db'
         self.homeDir = get_new_environment_path()
@@ -125,11 +155,6 @@ class AssociateErrorTestCase(unittest.TestCase):
 
 
 class AssociateTestCase(unittest.TestCase):
-    import sys
-    if sys.version_info < (2, 4) :
-        def assertTrue(self, expr, msg=None):
-            self.failUnless(expr,msg=msg)
-
     keytype = ''
     envFlags = 0
     dbFlags = 0
@@ -219,22 +244,21 @@ class AssociateTestCase(unittest.TestCase):
 
         return self._associateAfterDB(self.getGenre)
 
-    if db.version() >= (4, 6):
-        def test03_associateWithDB(self):
-            if verbose:
-                print '\n', '-=' * 30
-                print "Running %s.test03_associateWithDB..." % \
-                      self.__class__.__name__
+    def test03_associateWithDB(self):
+        if verbose:
+            print '\n', '-=' * 30
+            print "Running %s.test03_associateWithDB..." % \
+                  self.__class__.__name__
 
-            return self._associateWithDB(self.getGenreList)
+        return self._associateWithDB(self.getGenreList)
 
-        def test04_associateAfterDB(self):
-            if verbose:
-                print '\n', '-=' * 30
-                print "Running %s.test04_associateAfterDB..." % \
-                      self.__class__.__name__
+    def test04_associateAfterDB(self):
+        if verbose:
+            print '\n', '-=' * 30
+            print "Running %s.test04_associateAfterDB..." % \
+                  self.__class__.__name__
 
-            return self._associateAfterDB(self.getGenreList)
+        return self._associateAfterDB(self.getGenreList)
 
 
     def finish_test(self, secDB, txn=None):
