@@ -1,5 +1,5 @@
 """
-Copyright (c) 2008-2013, Jesus Cea Avion <jcea@jcea.es>
+Copyright (c) 2008-2014, Jesus Cea Avion <jcea@jcea.es>
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -189,10 +189,7 @@ class BasicTestCase(unittest.TestCase):
         try:
             d.delete('abcd')
         except db.DBNotFoundError, val:
-            if sys.version_info < (2, 6) :
-                self.assertEqual(val[0], db.DB_NOTFOUND)
-            else :
-                self.assertEqual(val.args[0], db.DB_NOTFOUND)
+            self.assertEqual(val.args[0], db.DB_NOTFOUND)
             if verbose: print val
         else:
             self.fail("expected exception")
@@ -211,10 +208,7 @@ class BasicTestCase(unittest.TestCase):
         try:
             d.put('abcd', 'this should fail', flags=db.DB_NOOVERWRITE)
         except db.DBKeyExistError, val:
-            if sys.version_info < (2, 6) :
-                self.assertEqual(val[0], db.DB_KEYEXIST)
-            else :
-                self.assertEqual(val.args[0], db.DB_KEYEXIST)
+            self.assertEqual(val.args[0], db.DB_KEYEXIST)
             if verbose: print val
         else:
             self.fail("expected exception")
@@ -364,10 +358,7 @@ class BasicTestCase(unittest.TestCase):
                 rec = c.next()
             except db.DBNotFoundError, val:
                 if get_raises_error:
-                    if sys.version_info < (2, 6) :
-                        self.assertEqual(val[0], db.DB_NOTFOUND)
-                    else :
-                        self.assertEqual(val.args[0], db.DB_NOTFOUND)
+                    self.assertEqual(val.args[0], db.DB_NOTFOUND)
                     if verbose: print val
                     rec = None
                 else:
@@ -388,10 +379,7 @@ class BasicTestCase(unittest.TestCase):
                 rec = c.prev()
             except db.DBNotFoundError, val:
                 if get_raises_error:
-                    if sys.version_info < (2, 6) :
-                        self.assertEqual(val[0], db.DB_NOTFOUND)
-                    else :
-                        self.assertEqual(val.args[0], db.DB_NOTFOUND)
+                    self.assertEqual(val.args[0], db.DB_NOTFOUND)
                     if verbose: print val
                     rec = None
                 else:
@@ -414,10 +402,7 @@ class BasicTestCase(unittest.TestCase):
         try:
             n = c.set('bad key')
         except db.DBNotFoundError, val:
-            if sys.version_info < (2, 6) :
-                self.assertEqual(val[0], db.DB_NOTFOUND)
-            else :
-                self.assertEqual(val.args[0], db.DB_NOTFOUND)
+            self.assertEqual(val.args[0], db.DB_NOTFOUND)
             if verbose: print val
         else:
             if set_raises_error:
@@ -431,10 +416,7 @@ class BasicTestCase(unittest.TestCase):
         try:
             n = c.get_both('0404', 'bad data')
         except db.DBNotFoundError, val:
-            if sys.version_info < (2, 6) :
-                self.assertEqual(val[0], db.DB_NOTFOUND)
-            else :
-                self.assertEqual(val.args[0], db.DB_NOTFOUND)
+            self.assertEqual(val.args[0], db.DB_NOTFOUND)
             if verbose: print val
         else:
             if get_raises_error:
@@ -463,10 +445,7 @@ class BasicTestCase(unittest.TestCase):
             rec = c.current()
         except db.DBKeyEmptyError, val:
             if get_raises_error:
-                if sys.version_info < (2, 6) :
-                    self.assertEqual(val[0], db.DB_KEYEMPTY)
-                else :
-                    self.assertEqual(val.args[0], db.DB_KEYEMPTY)
+                self.assertEqual(val.args[0], db.DB_KEYEMPTY)
                 if verbose: print val
             else:
                 self.fail("unexpected DBKeyEmptyError")
@@ -511,10 +490,7 @@ class BasicTestCase(unittest.TestCase):
                 # a bug may cause a NULL pointer dereference...
                 getattr(c, method)(*args)
             except db.DBError, val:
-                if sys.version_info < (2, 6) :
-                    self.assertEqual(val[0], 0)
-                else :
-                    self.assertEqual(val.args[0], 0)
+                self.assertEqual(val.args[0], 0)
                 if verbose: print val
             else:
                 self.fail("no exception raised when using a buggy cursor's"
@@ -566,14 +542,13 @@ class BasicTestCase(unittest.TestCase):
         self.assertEqual(old, 1)
         self.test03_SimpleCursorStuff(get_raises_error=0, set_raises_error=0)
 
-    if db.version() >= (4, 6):
-        def test03d_SimpleCursorPriority(self) :
-            c = self.d.cursor()
-            c.set_priority(db.DB_PRIORITY_VERY_LOW)  # Positional
-            self.assertEqual(db.DB_PRIORITY_VERY_LOW, c.get_priority())
-            c.set_priority(priority=db.DB_PRIORITY_HIGH)  # Keyword
-            self.assertEqual(db.DB_PRIORITY_HIGH, c.get_priority())
-            c.close()
+    def test03d_SimpleCursorPriority(self) :
+        c = self.d.cursor()
+        c.set_priority(db.DB_PRIORITY_VERY_LOW)  # Positional
+        self.assertEqual(db.DB_PRIORITY_VERY_LOW, c.get_priority())
+        c.set_priority(priority=db.DB_PRIORITY_HIGH)  # Keyword
+        self.assertEqual(db.DB_PRIORITY_HIGH, c.get_priority())
+        c.close()
 
     #----------------------------------------
 
@@ -648,31 +623,29 @@ class BasicTestCase(unittest.TestCase):
 
     #----------------------------------------
 
-    if db.version() >= (4, 6):
-        def test08_exists(self) :
-            self.d.put("abcde", "ABCDE")
-            self.assertTrue(self.d.exists("abcde") == True,
-                    "DB->exists() returns wrong value")
-            self.assertTrue(self.d.exists("x") == False,
-                    "DB->exists() returns wrong value")
+    def test08_exists(self) :
+        self.d.put("abcde", "ABCDE")
+        self.assertTrue(self.d.exists("abcde") == True,
+                "DB->exists() returns wrong value")
+        self.assertTrue(self.d.exists("x") == False,
+                "DB->exists() returns wrong value")
 
     #----------------------------------------
 
-    if db.version() >= (4, 7):
-        def test_compact(self) :
-            d = self.d
-            self.assertEqual(0, d.compact(flags=db.DB_FREELIST_ONLY))
-            self.assertEqual(0, d.compact(flags=db.DB_FREELIST_ONLY))
-            d.put("abcde", "ABCDE");
-            d.put("bcde", "BCDE");
-            d.put("abc", "ABC");
-            d.put("monty", "python");
-            d.delete("abc")
-            d.delete("bcde")
-            d.compact(start='abcde', stop='monty', txn=None,
-                    compact_fillpercent=42, compact_pages=1,
-                    compact_timeout=50000000,
-                    flags=db.DB_FREELIST_ONLY|db.DB_FREE_SPACE)
+    def test_compact(self) :
+        d = self.d
+        self.assertEqual(0, d.compact(flags=db.DB_FREELIST_ONLY))
+        self.assertEqual(0, d.compact(flags=db.DB_FREELIST_ONLY))
+        d.put("abcde", "ABCDE");
+        d.put("bcde", "BCDE");
+        d.put("abc", "ABC");
+        d.put("monty", "python");
+        d.delete("abc")
+        d.delete("bcde")
+        d.compact(start='abcde', stop='monty', txn=None,
+                compact_fillpercent=42, compact_pages=1,
+                compact_timeout=50000000,
+                flags=db.DB_FREELIST_ONLY|db.DB_FREE_SPACE)
 
     #----------------------------------------
 
@@ -732,8 +705,7 @@ class BasicHashWithEnvTestCase(BasicWithEnvTestCase):
 #----------------------------------------------------------------------
 
 class BasicTransactionTestCase(BasicTestCase):
-    if (sys.version_info < (2, 7)) or ((sys.version_info >= (3, 0)) and
-            (sys.version_info < (3, 2))) :
+    if sys.version_info < (2, 7) :
         def assertIn(self, a, b, msg=None) :
             return self.assertTrue(a in b, msg=msg)
 
@@ -814,17 +786,16 @@ class BasicTransactionTestCase(BasicTestCase):
 
     #----------------------------------------
 
-    if db.version() >= (4, 6):
-        def test08_exists(self) :
-            txn = self.env.txn_begin()
-            self.d.put("abcde", "ABCDE", txn=txn)
-            txn.commit()
-            txn = self.env.txn_begin()
-            self.assertTrue(self.d.exists("abcde", txn=txn) == True,
-                    "DB->exists() returns wrong value")
-            self.assertTrue(self.d.exists("x", txn=txn) == False,
-                    "DB->exists() returns wrong value")
-            txn.abort()
+    def test08_exists(self) :
+        txn = self.env.txn_begin()
+        self.d.put("abcde", "ABCDE", txn=txn)
+        txn.commit()
+        txn = self.env.txn_begin()
+        self.assertTrue(self.d.exists("abcde", txn=txn) == True,
+                "DB->exists() returns wrong value")
+        self.assertTrue(self.d.exists("x", txn=txn) == False,
+                "DB->exists() returns wrong value")
+        txn.abort()
 
     #----------------------------------------
 
@@ -868,24 +839,23 @@ class BasicTransactionTestCase(BasicTestCase):
     #----------------------------------------
 
 
-    if db.version() >= (4, 4):
-        def test_txn_name(self) :
-            txn=self.env.txn_begin()
-            self.assertEqual(txn.get_name(), "")
-            txn.set_name("XXYY")
-            self.assertEqual(txn.get_name(), "XXYY")
-            txn.set_name("")
-            self.assertEqual(txn.get_name(), "")
-            txn.abort()
+    def test_txn_name(self) :
+        txn=self.env.txn_begin()
+        self.assertEqual(txn.get_name(), "")
+        txn.set_name("XXYY")
+        self.assertEqual(txn.get_name(), "XXYY")
+        txn.set_name("")
+        self.assertEqual(txn.get_name(), "")
+        txn.abort()
 
     #----------------------------------------
 
 
-        def test_txn_set_timeout(self) :
-            txn=self.env.txn_begin()
-            txn.set_timeout(1234567, db.DB_SET_LOCK_TIMEOUT)
-            txn.set_timeout(2345678, flags=db.DB_SET_TXN_TIMEOUT)
-            txn.abort()
+    def test_txn_set_timeout(self) :
+        txn=self.env.txn_begin()
+        txn.set_timeout(1234567, db.DB_SET_LOCK_TIMEOUT)
+        txn.set_timeout(2345678, flags=db.DB_SET_TXN_TIMEOUT)
+        txn.abort()
 
     #----------------------------------------
 
