@@ -1,3 +1,38 @@
+"""
+Copyright (c) 2008-2014, Jesus Cea Avion <jcea@jcea.es>
+All rights reserved.
+
+Redistribution and use in source and binary forms, with or without
+modification, are permitted provided that the following conditions
+are met:
+
+    1. Redistributions of source code must retain the above copyright
+    notice, this list of conditions and the following disclaimer.
+
+    2. Redistributions in binary form must reproduce the above
+    copyright notice, this list of conditions and the following
+    disclaimer in the documentation and/or other materials provided
+    with the distribution.
+
+    3. Neither the name of Jesus Cea Avion nor the names of its
+    contributors may be used to endorse or promote products derived
+    from this software without specific prior written permission.
+
+    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
+    CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
+    INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
+    MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
+    BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
+            TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+            DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
+    ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
+    TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
+    THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+    SUCH DAMAGE.
+    """
+
 """
 Basic TestCases for BTree and hash DBs, with and without a DBEnv, with
 various DB flags, etc.
@@ -9,6 +44,7 @@ import string
 from pprint import pprint
 import unittest
 import time
+import sys
 
 from .test_all import db, test_support, verbose, get_new_environment_path, \
         get_new_database_path
@@ -44,13 +80,6 @@ class BasicTestCase(unittest.TestCase):
 
     _numKeys      = 1002    # PRIVATE.  NOTE: must be an even value
 
-    import sys
-    if sys.version_info < (2, 4):
-        def assertTrue(self, expr, msg=None):
-            self.failUnless(expr,msg=msg)
-        def assertFalse(self, expr, msg=None):
-            self.failIf(expr,msg=msg)
-
     def setUp(self):
         if self.useEnv:
             self.homeDir=get_new_environment_path()
@@ -160,11 +189,7 @@ class BasicTestCase(unittest.TestCase):
         try:
             d.delete('abcd')
         except db.DBNotFoundError as val:
-            import sys
-            if sys.version_info < (2, 6) :
-                self.assertEqual(val[0], db.DB_NOTFOUND)
-            else :
-                self.assertEqual(val.args[0], db.DB_NOTFOUND)
+            self.assertEqual(val.args[0], db.DB_NOTFOUND)
             if verbose: print(val)
         else:
             self.fail("expected exception")
@@ -183,11 +208,7 @@ class BasicTestCase(unittest.TestCase):
         try:
             d.put('abcd', 'this should fail', flags=db.DB_NOOVERWRITE)
         except db.DBKeyExistError as val:
-            import sys
-            if sys.version_info < (2, 6) :
-                self.assertEqual(val[0], db.DB_KEYEXIST)
-            else :
-                self.assertEqual(val.args[0], db.DB_KEYEXIST)
+            self.assertEqual(val.args[0], db.DB_KEYEXIST)
             if verbose: print(val)
         else:
             self.fail("expected exception")
@@ -337,11 +358,7 @@ class BasicTestCase(unittest.TestCase):
                 rec = next(c)
             except db.DBNotFoundError as val:
                 if get_raises_error:
-                    import sys
-                    if sys.version_info < (2, 6) :
-                        self.assertEqual(val[0], db.DB_NOTFOUND)
-                    else :
-                        self.assertEqual(val.args[0], db.DB_NOTFOUND)
+                    self.assertEqual(val.args[0], db.DB_NOTFOUND)
                     if verbose: print(val)
                     rec = None
                 else:
@@ -362,11 +379,7 @@ class BasicTestCase(unittest.TestCase):
                 rec = c.prev()
             except db.DBNotFoundError as val:
                 if get_raises_error:
-                    import sys
-                    if sys.version_info < (2, 6) :
-                        self.assertEqual(val[0], db.DB_NOTFOUND)
-                    else :
-                        self.assertEqual(val.args[0], db.DB_NOTFOUND)
+                    self.assertEqual(val.args[0], db.DB_NOTFOUND)
                     if verbose: print(val)
                     rec = None
                 else:
@@ -389,11 +402,7 @@ class BasicTestCase(unittest.TestCase):
         try:
             n = c.set('bad key')
         except db.DBNotFoundError as val:
-            import sys
-            if sys.version_info < (2, 6) :
-                self.assertEqual(val[0], db.DB_NOTFOUND)
-            else :
-                self.assertEqual(val.args[0], db.DB_NOTFOUND)
+            self.assertEqual(val.args[0], db.DB_NOTFOUND)
             if verbose: print(val)
         else:
             if set_raises_error:
@@ -407,11 +416,7 @@ class BasicTestCase(unittest.TestCase):
         try:
             n = c.get_both('0404', 'bad data')
         except db.DBNotFoundError as val:
-            import sys
-            if sys.version_info < (2, 6) :
-                self.assertEqual(val[0], db.DB_NOTFOUND)
-            else :
-                self.assertEqual(val.args[0], db.DB_NOTFOUND)
+            self.assertEqual(val.args[0], db.DB_NOTFOUND)
             if verbose: print(val)
         else:
             if get_raises_error:
@@ -440,11 +445,7 @@ class BasicTestCase(unittest.TestCase):
             rec = c.current()
         except db.DBKeyEmptyError as val:
             if get_raises_error:
-                import sys
-                if sys.version_info < (2, 6) :
-                    self.assertEqual(val[0], db.DB_KEYEMPTY)
-                else :
-                    self.assertEqual(val.args[0], db.DB_KEYEMPTY)
+                self.assertEqual(val.args[0], db.DB_KEYEMPTY)
                 if verbose: print(val)
             else:
                 self.fail("unexpected DBKeyEmptyError")
@@ -489,11 +490,7 @@ class BasicTestCase(unittest.TestCase):
                 # a bug may cause a NULL pointer dereference...
                 getattr(c, method)(*args)
             except db.DBError as val:
-                import sys
-                if sys.version_info < (2, 6) :
-                    self.assertEqual(val[0], 0)
-                else :
-                    self.assertEqual(val.args[0], 0)
+                self.assertEqual(val.args[0], 0)
                 if verbose: print(val)
             else:
                 self.fail("no exception raised when using a buggy cursor's"
@@ -545,14 +542,13 @@ class BasicTestCase(unittest.TestCase):
         self.assertEqual(old, 1)
         self.test03_SimpleCursorStuff(get_raises_error=0, set_raises_error=0)
 
-    if db.version() >= (4, 6):
-        def test03d_SimpleCursorPriority(self) :
-            c = self.d.cursor()
-            c.set_priority(db.DB_PRIORITY_VERY_LOW)  # Positional
-            self.assertEqual(db.DB_PRIORITY_VERY_LOW, c.get_priority())
-            c.set_priority(priority=db.DB_PRIORITY_HIGH)  # Keyword
-            self.assertEqual(db.DB_PRIORITY_HIGH, c.get_priority())
-            c.close()
+    def test03d_SimpleCursorPriority(self) :
+        c = self.d.cursor()
+        c.set_priority(db.DB_PRIORITY_VERY_LOW)  # Positional
+        self.assertEqual(db.DB_PRIORITY_VERY_LOW, c.get_priority())
+        c.set_priority(priority=db.DB_PRIORITY_HIGH)  # Keyword
+        self.assertEqual(db.DB_PRIORITY_HIGH, c.get_priority())
+        c.close()
 
     #----------------------------------------
 
@@ -627,31 +623,29 @@ class BasicTestCase(unittest.TestCase):
 
     #----------------------------------------
 
-    if db.version() >= (4, 6):
-        def test08_exists(self) :
-            self.d.put("abcde", "ABCDE")
-            self.assertTrue(self.d.exists("abcde") == True,
-                    "DB->exists() returns wrong value")
-            self.assertTrue(self.d.exists("x") == False,
-                    "DB->exists() returns wrong value")
+    def test08_exists(self) :
+        self.d.put("abcde", "ABCDE")
+        self.assertTrue(self.d.exists("abcde") == True,
+                "DB->exists() returns wrong value")
+        self.assertTrue(self.d.exists("x") == False,
+                "DB->exists() returns wrong value")
 
     #----------------------------------------
 
-    if db.version() >= (4, 7):
-        def test_compact(self) :
-            d = self.d
-            self.assertEqual(0, d.compact(flags=db.DB_FREELIST_ONLY))
-            self.assertEqual(0, d.compact(flags=db.DB_FREELIST_ONLY))
-            d.put("abcde", "ABCDE");
-            d.put("bcde", "BCDE");
-            d.put("abc", "ABC");
-            d.put("monty", "python");
-            d.delete("abc")
-            d.delete("bcde")
-            d.compact(start='abcde', stop='monty', txn=None,
-                    compact_fillpercent=42, compact_pages=1,
-                    compact_timeout=50000000,
-                    flags=db.DB_FREELIST_ONLY|db.DB_FREE_SPACE)
+    def test_compact(self) :
+        d = self.d
+        self.assertEqual(0, d.compact(flags=db.DB_FREELIST_ONLY))
+        self.assertEqual(0, d.compact(flags=db.DB_FREELIST_ONLY))
+        d.put("abcde", "ABCDE");
+        d.put("bcde", "BCDE");
+        d.put("abc", "ABC");
+        d.put("monty", "python");
+        d.delete("abc")
+        d.delete("bcde")
+        d.compact(start='abcde', stop='monty', txn=None,
+                compact_fillpercent=42, compact_pages=1,
+                compact_timeout=50000000,
+                flags=db.DB_FREELIST_ONLY|db.DB_FREE_SPACE)
 
     #----------------------------------------
 
@@ -711,13 +705,7 @@ class BasicHashWithEnvTestCase(BasicWithEnvTestCase):
 #----------------------------------------------------------------------
 
 class BasicTransactionTestCase(BasicTestCase):
-    import sys
-    if sys.version_info < (2, 4):
-        def assertTrue(self, expr, msg=None):
-            return self.failUnless(expr,msg=msg)
-
-    if (sys.version_info < (2, 7)) or ((sys.version_info >= (3, 0)) and
-            (sys.version_info < (3, 2))) :
+    if sys.version_info < (2, 7) :
         def assertIn(self, a, b, msg=None) :
             return self.assertTrue(a in b, msg=msg)
 
@@ -798,17 +786,16 @@ class BasicTransactionTestCase(BasicTestCase):
 
     #----------------------------------------
 
-    if db.version() >= (4, 6):
-        def test08_exists(self) :
-            txn = self.env.txn_begin()
-            self.d.put("abcde", "ABCDE", txn=txn)
-            txn.commit()
-            txn = self.env.txn_begin()
-            self.assertTrue(self.d.exists("abcde", txn=txn) == True,
-                    "DB->exists() returns wrong value")
-            self.assertTrue(self.d.exists("x", txn=txn) == False,
-                    "DB->exists() returns wrong value")
-            txn.abort()
+    def test08_exists(self) :
+        txn = self.env.txn_begin()
+        self.d.put("abcde", "ABCDE", txn=txn)
+        txn.commit()
+        txn = self.env.txn_begin()
+        self.assertTrue(self.d.exists("abcde", txn=txn) == True,
+                "DB->exists() returns wrong value")
+        self.assertTrue(self.d.exists("x", txn=txn) == False,
+                "DB->exists() returns wrong value")
+        txn.abort()
 
     #----------------------------------------
 
@@ -852,24 +839,23 @@ class BasicTransactionTestCase(BasicTestCase):
     #----------------------------------------
 
 
-    if db.version() >= (4, 4):
-        def test_txn_name(self) :
-            txn=self.env.txn_begin()
-            self.assertEqual(txn.get_name(), "")
-            txn.set_name("XXYY")
-            self.assertEqual(txn.get_name(), "XXYY")
-            txn.set_name("")
-            self.assertEqual(txn.get_name(), "")
-            txn.abort()
+    def test_txn_name(self) :
+        txn=self.env.txn_begin()
+        self.assertEqual(txn.get_name(), "")
+        txn.set_name("XXYY")
+        self.assertEqual(txn.get_name(), "XXYY")
+        txn.set_name("")
+        self.assertEqual(txn.get_name(), "")
+        txn.abort()
 
     #----------------------------------------
 
 
-        def test_txn_set_timeout(self) :
-            txn=self.env.txn_begin()
-            txn.set_timeout(1234567, db.DB_SET_LOCK_TIMEOUT)
-            txn.set_timeout(2345678, flags=db.DB_SET_TXN_TIMEOUT)
-            txn.abort()
+    def test_txn_set_timeout(self) :
+        txn=self.env.txn_begin()
+        txn.set_timeout(1234567, db.DB_SET_LOCK_TIMEOUT)
+        txn.set_timeout(2345678, flags=db.DB_SET_TXN_TIMEOUT)
+        txn.abort()
 
     #----------------------------------------
 
@@ -1095,11 +1081,6 @@ class HashMultiDBTestCase(BasicMultiDBTestCase):
 
 
 class PrivateObject(unittest.TestCase) :
-    import sys
-    if sys.version_info < (2, 4):
-        def assertTrue(self, expr, msg=None):
-            self.failUnless(expr,msg=msg)
-
     def tearDown(self) :
         del self.obj
 
@@ -1113,7 +1094,6 @@ class PrivateObject(unittest.TestCase) :
         self.assertTrue(a is b)  # Object identity
 
     def test03_leak_assignment(self) :
-        import sys
         a = "example of private object"
         refcount = sys.getrefcount(a)
         self.obj.set_private(a)
@@ -1122,7 +1102,6 @@ class PrivateObject(unittest.TestCase) :
         self.assertEqual(refcount, sys.getrefcount(a))
 
     def test04_leak_GC(self) :
-        import sys
         a = "example of private object"
         refcount = sys.getrefcount(a)
         self.obj.set_private(a)
@@ -1138,11 +1117,6 @@ class DBPrivateObject(PrivateObject) :
         self.obj = db.DB()
 
 class CrashAndBurn(unittest.TestCase) :
-    import sys
-    if sys.version_info < (2, 4):
-        def assertTrue(self, expr, msg=None):
-            self.failUnless(expr,msg=msg)
-
     #def test01_OpenCrash(self) :
     #    # See http://bugs.python.org/issue3307
     #    self.assertRaises(db.DBInvalidArgError, db.DB, None, 65535)
