@@ -1,3 +1,38 @@
+"""
+Copyright (c) 2008-2014, Jesus Cea Avion <jcea@jcea.es>
+All rights reserved.
+
+Redistribution and use in source and binary forms, with or without
+modification, are permitted provided that the following conditions
+are met:
+
+    1. Redistributions of source code must retain the above copyright
+    notice, this list of conditions and the following disclaimer.
+
+    2. Redistributions in binary form must reproduce the above
+    copyright notice, this list of conditions and the following
+    disclaimer in the documentation and/or other materials provided
+    with the distribution.
+
+    3. Neither the name of Jesus Cea Avion nor the names of its
+    contributors may be used to endorse or promote products derived
+    from this software without specific prior written permission.
+
+    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
+    CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
+    INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
+    MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
+    BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
+            TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+            DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
+    ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
+    TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
+    THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+    SUCH DAMAGE.
+    """
+
 import unittest
 import os, glob
 
@@ -7,13 +42,6 @@ from .test_all import db, test_support, get_new_environment_path, \
 #----------------------------------------------------------------------
 
 class DB(unittest.TestCase):
-    import sys
-    if sys.version_info < (2, 4) :
-        def assertTrue(self, expr, msg=None):
-            self.failUnless(expr,msg=msg)
-        def assertFalse(self, expr, msg=None):
-            self.failIf(expr,msg=msg)
-
     def setUp(self):
         self.path = get_new_database_path()
         self.db = db.DB()
@@ -55,20 +83,18 @@ class DB_general(DB) :
         self.assertEqual(4321, self.db.get_lorder())
         self.assertRaises(db.DBInvalidArgError, self.db.set_lorder, 9182)
 
-    if db.version() >= (4, 6) :
-        def test_priority(self) :
-            flags = [db.DB_PRIORITY_VERY_LOW, db.DB_PRIORITY_LOW,
-                    db.DB_PRIORITY_DEFAULT, db.DB_PRIORITY_HIGH,
-                    db.DB_PRIORITY_VERY_HIGH]
-            for flag in flags :
-                self.db.set_priority(flag)
-                self.assertEqual(flag, self.db.get_priority())
+    def test_priority(self) :
+        flags = [db.DB_PRIORITY_VERY_LOW, db.DB_PRIORITY_LOW,
+                db.DB_PRIORITY_DEFAULT, db.DB_PRIORITY_HIGH,
+                db.DB_PRIORITY_VERY_HIGH]
+        for flag in flags :
+            self.db.set_priority(flag)
+            self.assertEqual(flag, self.db.get_priority())
 
-    if db.version() >= (4, 3) :
-        def test_get_transactional(self) :
-            self.assertFalse(self.db.get_transactional())
-            self.db.open(self.path, dbtype=db.DB_HASH, flags = db.DB_CREATE)
-            self.assertFalse(self.db.get_transactional())
+    def test_get_transactional(self) :
+        self.assertFalse(self.db.get_transactional())
+        self.db.open(self.path, dbtype=db.DB_HASH, flags = db.DB_CREATE)
+        self.assertFalse(self.db.get_transactional())
 
 class DB_hash(DB) :
     def test_h_ffactor(self) :
@@ -116,13 +142,12 @@ class DB_txn(DB) :
         self.assertEqual(db.DB_TXN_NOT_DURABLE | db.DB_CHKSUM,
                 self.db.get_flags())
 
-    if db.version() >= (4, 3) :
-        def test_get_transactional(self) :
-            self.assertFalse(self.db.get_transactional())
-            # DB_AUTO_COMMIT = Implicit transaction
-            self.db.open("XXX", dbtype=db.DB_HASH,
-                    flags = db.DB_CREATE | db.DB_AUTO_COMMIT)
-            self.assertTrue(self.db.get_transactional())
+    def test_get_transactional(self) :
+        self.assertFalse(self.db.get_transactional())
+        # DB_AUTO_COMMIT = Implicit transaction
+        self.db.open("XXX", dbtype=db.DB_HASH,
+                flags = db.DB_CREATE | db.DB_AUTO_COMMIT)
+        self.assertTrue(self.db.get_transactional())
 
 class DB_recno(DB) :
     def test_re_pad(self) :
