@@ -1,3 +1,38 @@
+"""
+Copyright (c) 2008-2014, Jesus Cea Avion <jcea@jcea.es>
+All rights reserved.
+
+Redistribution and use in source and binary forms, with or without
+modification, are permitted provided that the following conditions
+are met:
+
+    1. Redistributions of source code must retain the above copyright
+    notice, this list of conditions and the following disclaimer.
+
+    2. Redistributions in binary form must reproduce the above
+    copyright notice, this list of conditions and the following
+    disclaimer in the documentation and/or other materials provided
+    with the distribution.
+
+    3. Neither the name of Jesus Cea Avion nor the names of its
+    contributors may be used to endorse or promote products derived
+    from this software without specific prior written permission.
+
+    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
+    CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
+    INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
+    MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
+    BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+    EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
+            TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+            DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
+    ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
+    TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
+    THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+    SUCH DAMAGE.
+    """
+
 """TestCases for distributed transactions.
 """
 
@@ -7,23 +42,11 @@ import unittest
 from .test_all import db, test_support, get_new_environment_path, \
         get_new_database_path
 
-try :
-    a=set()
-except : # Python 2.3
-    from sets import Set as set
-else :
-    del a
-
 from .test_all import verbose
 
 #----------------------------------------------------------------------
 
 class DBTxn_distributed(unittest.TestCase):
-    import sys
-    if sys.version_info < (2, 4) :
-        def assertTrue(self, expr, msg=None):
-            self.failUnless(expr,msg=msg)
-
     num_txns=1234
     nosync=True
     must_open_db=False
@@ -54,7 +77,7 @@ class DBTxn_distributed(unittest.TestCase):
         return self._create_env(must_open_db=True)
 
     def _destroy_env(self):
-        if self.nosync or (db.version()[:2] == (4,6)):  # Known bug
+        if self.nosync :
             self.dbenv.log_flush()
         self.db.close()
         self.dbenv.close()
@@ -151,12 +174,10 @@ class DBTxn_distributedSYNC_must_open_db(DBTxn_distributed):
 
 def test_suite():
     suite = unittest.TestSuite()
-    if db.version() >= (4,5) :
-        suite.addTest(unittest.makeSuite(DBTxn_distributed))
-        suite.addTest(unittest.makeSuite(DBTxn_distributedSYNC))
-    if db.version() >= (4,6) :
-        suite.addTest(unittest.makeSuite(DBTxn_distributed_must_open_db))
-        suite.addTest(unittest.makeSuite(DBTxn_distributedSYNC_must_open_db))
+    suite.addTest(unittest.makeSuite(DBTxn_distributed))
+    suite.addTest(unittest.makeSuite(DBTxn_distributedSYNC))
+    suite.addTest(unittest.makeSuite(DBTxn_distributed_must_open_db))
+    suite.addTest(unittest.makeSuite(DBTxn_distributedSYNC_must_open_db))
     return suite
 
 
