@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2008-2013, Jesus Cea Avion <jcea@jcea.es>
+Copyright (c) 2008-2014, Jesus Cea Avion <jcea@jcea.es>
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -157,9 +157,9 @@ if os.name == 'posix':
         lflags_arg = LFLAGS + LIBS
 
     # Supported Berkeley DB versions, in order of preference.
-    db_ver_list = ((6, 0),
+    db_ver_list = ((6, 1), (6, 0),
             (5, 3), (5, 2), (5, 1), (5, 0),
-            (4, 8), (4, 7), (4, 6), (4, 5), (4, 4), (4, 3))
+            (4, 8), (4, 7))
     db_ver = None
 
     # If we were not told where it is, go looking for it.
@@ -216,7 +216,10 @@ if os.name == 'posix':
                 f = os.path.join(d, "db.h")
                 if debug: print "db: looking for db.h in", f
                 if os.path.exists(f):
-                    f = open(f).read()
+                    # This should move to "with" when we drop support for python 2.4 and 2.5
+                    fichero = open(f)
+                    f = fichero.read()
+                    fichero.close()
                     m = re.search(r"#define\WDB_VERSION_MAJOR\W(\d+)", f)
                     if m:
                         db_major = int(m.group(1))
@@ -332,7 +335,10 @@ if os.name == 'posix':
 
     # read db.h to figure out what version of Berkeley DB this is
     ver = None
-    db_h_lines = open(os.path.join(incdir, 'db.h'), 'r').readlines()
+    # This should move to "with" when we drop support for Python 2.4 and 2.5
+    f = open(os.path.join(incdir, 'db.h'), 'r')
+    db_h_lines = f.readlines()
+    f.close()
     db_ver_re = re.compile(
         r'^#define\s+DB_VERSION_STRING\s.*Berkeley DB (\d+\.\d+).*')
     db_ver2 = db_ver
@@ -375,7 +381,10 @@ elif os.name == 'nt':
 
     # read db.h to figure out what version of Berkeley DB this is
     ver = None
-    db_h_lines = open(os.path.join(incdir, 'db.h'), 'r').readlines()
+    # We should move this to "with" when we drop support for Python 2.4 and 2.5.
+    f = open(os.path.join(incdir, 'db.h'), 'r')
+    db_h_lines = f.readlines()
+    f.close()
     db_ver_re = re.compile(
         r'^#define\s+DB_VERSION_STRING\s.*Berkeley DB (\d+\.\d+).*')
     for line in db_h_lines:
@@ -410,7 +419,7 @@ elif os.name == 'nt':
              ("bsddb3/test", glob.glob("test/*.py"))
              ]
 
-if (db_ver in ((6,0),)) and \
+if (db_ver in ((6, 0), (6, 1))) and \
   ("YES_I_HAVE_THE_RIGHT_TO_USE_THIS_BERKELEY_DB_VERSION" not in os.environ) :
     print (
         "\n"
@@ -430,7 +439,7 @@ if (db_ver in ((6,0),)) and \
         "any value, and try to install this python library again.\n"
         "\n"
         "  2. In any other case, you have to link to a previous version "
-        "of Berkeley DB. Remove Berlekey DB version 6.0 and let this "
+        "of Berkeley DB. Remove Berlekey DB version 6.x and let this "
         "python library try to locate an older version of the "
         "Berkeley DB library in your system. Alternatively, you can "
         "define the environment variable 'BERKELEYDB_DIR', or "
@@ -471,6 +480,10 @@ the website for more details on the types and methods provided. The goal is to
 mirror most of the real Berkeley DB API so fall back to the Oracle Berkeley DB
 documentation as appropriate.
 
+If you need to support ancient versiones of Python and/or Berkeley DB , you can
+use old releases of this bindings.
+
+
 `Homepage <http://www.jcea.es/programacion/
 pybsddb.htm>`__ --
 `Documentation <http://www.jcea.es/programacion/
@@ -511,14 +524,12 @@ pybsddb_doc/>`__ --
                     'Topic :: Software Development',
                     'Topic :: System :: Clustering',
                     'Programming Language :: Python :: 2',
-                    'Programming Language :: Python :: 2.4',
-                    'Programming Language :: Python :: 2.5',
                     'Programming Language :: Python :: 2.6',
                     'Programming Language :: Python :: 2.7',
                     'Programming Language :: Python :: 3',
-                    'Programming Language :: Python :: 3.1',
                     'Programming Language :: Python :: 3.2',
                     'Programming Language :: Python :: 3.3',
+                    'Programming Language :: Python :: 3.4',
                     ],
       )
 
