@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2008-2013, Jesus Cea Avion <jcea@jcea.es>
+Copyright (c) 2008-2014, Jesus Cea Avion <jcea@jcea.es>
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -54,10 +54,10 @@ import os
 os.environ['YES_I_HAVE_THE_RIGHT_TO_USE_THIS_BERKELEY_DB_VERSION'] = ''
 
 def do_matrix_check() :
-  python_versions=('2.4', '2.5', '2.6', '2.7', '3.1', '3.2', '3.3', '3.4')
-  berkeleydb_versions=('4.3', '4.4', '4.5', '4.6', '4.7', '4.8',
+  python_versions=('2.6', '2.7', '3.2', '3.3', '3.4')
+  berkeleydb_versions=('4.7', '4.8',
                        '5.0', '5.1', '5.2', '5.3',
-                       '6.0')
+                       '6.0', '6.1')
 
   warning_level=("-Wdefault", "-Werror")[1]
 
