@@ -292,7 +292,7 @@ class PathInit:
         # Hack sys.path
         self.cwd = os.getcwd()
         print 'Running tests from', self.cwd
-        sys.path.insert(0, os.path.join(self.cwd, self.libdir))
+        sys.path[0] = os.path.join(self.cwd, self.libdir)
 
 
 def match(rx, s):
@@ -314,7 +314,7 @@ class TestFileFinder:
             return
         # ignore tests that aren't in packages
         if not "__init__.py" in files:
-            if not files or files == ['CVS']:
+            if not files :
                 return
             print "not a package", dir
             return
